@@ -1,9 +1,9 @@
 use std::io;
 use std::time::Duration;
 
+use futures_util::AsyncReadExt;
 use slings::net::TcpStream;
 use slings::time::timeout;
-use slings::AsyncReadExt;
 
 fn main() -> io::Result<()> {
     slings::block_on(async {
