@@ -5,12 +5,12 @@ use io_uring::{opcode, types};
 
 use crate::driver::Action;
 
-pub struct Close {
+pub(crate) struct Close {
     fd: RawFd,
 }
 
 impl Action<Close> {
-    pub fn close(fd: RawFd) -> io::Result<Action<Close>> {
+    pub(crate) fn close(fd: RawFd) -> io::Result<Action<Close>> {
         let close = Close { fd };
         let entry = opcode::Close::new(types::Fd(close.fd)).build();
         Action::try_submit(close, entry)
