@@ -1,27 +1,25 @@
 use std::io;
-use std::net::SocketAddr;
 
 use io_uring::{opcode, types};
-use os_socketaddr::OsSocketAddr;
+use socket2::SockAddr;
 
 use crate::driver::{Action, SharedFd};
 
 pub(crate) struct Connect {
     fd: SharedFd,
-    os_socket_addr: OsSocketAddr,
+    sock_addr: SockAddr,
 }
 
 impl Action<Connect> {
-    pub(crate) fn connect(fd: &SharedFd, socket_addr: SocketAddr) -> io::Result<Action<Connect>> {
-        let os_socket_addr = OsSocketAddr::from(socket_addr);
+    pub(crate) fn connect(fd: &SharedFd, sock_addr: SockAddr) -> io::Result<Action<Connect>> {
         let connect = Connect {
             fd: fd.clone(),
-            os_socket_addr,
+            sock_addr,
         };
         let entry = opcode::Connect::new(
             types::Fd(connect.fd.raw_fd()),
-            connect.os_socket_addr.as_ptr(),
-            connect.os_socket_addr.len(),
+            connect.sock_addr.as_ptr(),
+            connect.sock_addr.len(),
         )
         .build();
         Action::submit(connect, entry)
