@@ -15,7 +15,6 @@ mod accept;
 mod action;
 mod close;
 mod connect;
-mod packet;
 mod read;
 mod recv;
 mod recvmsg;
@@ -23,13 +22,10 @@ mod send;
 mod sendmsg;
 mod shared_fd;
 mod shutdown;
-mod socket;
-mod stream;
 mod timeout;
 mod write;
 
 pub(crate) use action::Action;
-pub(crate) use packet::Packet;
 pub(crate) use read::Read;
 pub(crate) use recv::Recv;
 pub(crate) use recvmsg::RecvMsg;
@@ -37,8 +33,6 @@ pub(crate) use send::Send;
 pub(crate) use sendmsg::SendMsg;
 pub(crate) use shared_fd::SharedFd;
 pub(crate) use shutdown::Shutdown;
-pub(crate) use socket::Socket;
-pub(crate) use stream::Stream;
 pub(crate) use timeout::Timeout;
 pub(crate) use write::Write;
 
@@ -112,14 +106,14 @@ impl Driver {
         CURRENT.set(self, f)
     }
 
-    pub(crate) fn try_submit(&self, sqe: Entry) -> io::Result<usize> {
+    pub(crate) fn try_submit<T>(&self, action: T, sqe: Entry) -> io::Result<Action<T>> {
         if self.inner.try_borrow_mut().is_err() {
             return Err(io::ErrorKind::Other.into());
         }
-        self.submit(sqe)
+        self.submit(action, sqe)
     }
 
-    pub(crate) fn submit(&self, sqe: Entry) -> io::Result<usize> {
+    pub(crate) fn submit<T>(&self, action: T, sqe: Entry) -> io::Result<Action<T>> {
         let mut inner = self.inner.borrow_mut();
         let inner = &mut *inner;
         let key = inner.actions.insert(State::Submitted);
@@ -135,7 +129,11 @@ impl Driver {
             ring.submission().push(&sqe).expect("push entry fail");
         }
         ring.submit()?;
-        Ok(key)
+        Ok(Action {
+            driver: self.clone(),
+            action: Some(action),
+            key,
+        })
     }
 }
 
