@@ -23,6 +23,7 @@ where
     type Output = T;
 
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<T> {
-        (&mut self.f)(cx)
+        let f = &mut self.f;
+        f(cx)
     }
 }
